Library for EarthLCD ezLCD3xx line of products

Dependents:   ezLCDTest

/media/uploads/codeman/front.jpg /media/uploads/codeman/all.jpg /media/uploads/codeman/arlcd.jpg /media/uploads/codeman/side.jpg

Revision:
6:83cada1140d4
Parent:
5:4a6254e2012f
--- a/ezLCDLib.h	Thu May 02 02:32:26 2013 +0000
+++ b/ezLCDLib.h	Mon May 13 18:00:23 2013 +0000
@@ -212,12 +212,12 @@
     bool sync( void );
 
     /** Send a integer to the display
-    * @param i integer to send
+    * @param[in] i integer to send
     */
     void sendInt( int i );
 
     /** Get a integer from the display
-    * @param str string to put the data in
+    * @param[out] str string to put the data in
     *
     */
     int getInt( char *str );
@@ -269,51 +269,51 @@
 
     /** set pixel in current draw color at x y
      *
-     * @param x is the x coordinate
-     * @param y is the y coordinate
+     * @param[in] x is the x coordinate
+     * @param[in] y is the y coordinate
      */
     void plot(int x, int y);
 
     /** draw line from current x y to new x y
      *
-     * @param x is the x coordinate
-     * @param y is the y coordinate
+     * @param[in] x is the x coordinate
+     * @param[in] y is the y coordinate
      */
     void line(int x, int y);
 
     /** Set line drawing type
-    * @param type Options: 0 = solid, 1= dotted (1 pixel spacing between dots), 2 = dashed (2 pixel spacing between dashes)
+    * @param[in] type Options: 0 = solid, 1= dotted (1 pixel spacing between dots), 2 = dashed (2 pixel spacing between dashes)
     *
     *
     */
     void lineType( int type );
 
     /** Set line drawing width
-    * @param width in pixels
+    * @param[in] width in pixels
     *
     *
     */
     void lineWidth( int width );
     /** Draw circle in current color at current x y
      *
-     * @param radius diameter of circle
-     * @param filled  true for a filled box outline if false
+     * @param[in] radius diameter of circle
+     * @param[in] filled  true for a filled box outline if false
      */
     void circle(int radius, bool filled);
 
     /** draw a box from current x y to new x y
      *
      * @param x
      * @param y
      * @param filled  true for a filled box outline if false
      */
-    void box(int x, int y, bool filled);
+    void box(int width, int heigth, bool filled);
 
     /** set backlight brightness
      *
      * @param i is brightness 0=off 100=full in steps of 32
      */
-    void light(int i);
+    void light(int level);
 
     /** Send a command direct to display
     * @param str command string
@@ -375,6 +375,7 @@
     */
     void fontw( int id, char *str);
 
+    void fontw( int ID, int font);
     /**
     *
     *
@@ -269,51 +269,51 @@
     void circle(int radius, bool filled);
 
-    /** draw a box from current x y to new x y
+    /** draw a box from current x y of width and heigth
      *
@@ -269,51 +269,51 @@
      *
-     * @param x
-     * @param y
-     * @param filled  true for a filled box outline if false
+     * @param[in] width
+     * @param[in] heigth
+     * @param[in] filled  true for a filled box outline if false
      */
@@ -269,51 +269,51 @@
     /** set backlight brightness
      *
-     * @param i is brightness 0=off 100=full in steps of 32
+     * @param[in] level is brightness 0=off 100=full in steps of 32
      */